@@ -1,9 +1,9 @@
-from unittest.mock import Mock, patch
 from unittest import TestCase
 
 from samtranslator.model.eventsources.push import Schedule
 from samtranslator.model.lambda_ import LambdaFunction
 from samtranslator.model.exceptions import InvalidEventException
+from parameterized import parameterized
 
 
 class ScheduleEventSource(TestCase):
@@ -13,6 +13,27 @@ class ScheduleEventSource(TestCase):
         self.schedule_event_source.Schedule = "rate(1 minute)"
         self.func = LambdaFunction("func")
 
+    def test_to_cloudformation_returns_permission_and_schedule_resources(self):
+        resources = self.schedule_event_source.to_cloudformation(function=self.func)
+        self.assertEqual(len(resources), 2)
+        self.assertEqual(resources[0].resource_type, "AWS::Events::Rule")
+        self.assertEqual(resources[1].resource_type, "AWS::Lambda::Permission")
+
+        schedule = resources[0]
+        self.assertEqual(schedule.ScheduleExpression, "rate(1 minute)")
+        self.assertIsNone(schedule.State)
+
+    def test_to_cloudformation_transforms_enabled_boolean_to_state(self):
+        self.schedule_event_source.Enabled = True
+        resources = self.schedule_event_source.to_cloudformation(function=self.func)
+        schedule = resources[0]
+        self.assertEqual(schedule.State, "ENABLED")
+
+        self.schedule_event_source.Enabled = False
+        resources = self.schedule_event_source.to_cloudformation(function=self.func)
+        schedule = resources[0]
+        self.assertEqual(schedule.State, "DISABLED")
+
     def test_to_cloudformation_with_retry_policy(self):
         retry_policy = {"MaximumRetryAttempts": "10", "MaximumEventAgeInSeconds": "300"}
         self.schedule_event_source.RetryPolicy = retry_policy
@@ -70,3 +91,19 @@ class ScheduleEventSource(TestCase):
         self.schedule_event_source.DeadLetterConfig = dead_letter_config
         with self.assertRaises(InvalidEventException):
             self.schedule_event_source.to_cloudformation(function=self.func)
+
+    @parameterized.expand(
+        [
+            (True, "Enabled"),
+            (True, "Disabled"),
+            (True, {"FN:FakeIntrinsic": "something"}),
+            (False, "Enabled"),
+            (False, "Disabled"),
+            (False, {"FN:FakeIntrinsic": "something"}),
+        ]
+    )
+    def test_to_cloudformation_invalid_defined_both_enabled_and_state_provided(self, enabled_value, state_value):
+        self.schedule_event_source.Enabled = enabled_value
+        self.schedule_event_source.State = state_value
+        with self.assertRaises(InvalidEventException):
+            self.schedule_event_source.to_cloudformation(function=self.func)
